docs.rs failed to build irox-units-0.4.4
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
irox-units-0.5.0
IROX-Units
The little Units Library that could
Module Structure:
bounds- Bounding Boxes and Range Checksshapes- Ways to define and describe shapescircular-CircularAspectenum andCircularDimensionstruct, describes a circle by radius or diameter with appropriate length units.elliptical-Ellipsestruct, describes an ellipse using twoCircularDimensionaxes and an optionalCompassDirectionorientation of the first axis
units- Physical Quantitiesangle- Angle Types,Angle,AngleUnitsforDegreesandRadianscompass- Compass Types,Compass, and the absolute types:Heading,Track,Bearing,Course,Azimuth,CompassOffest, and the relative types:RelativeBearing
datasize- Computer Data Sizes,Bytes,Kilobytes, etcduration- ContainsDuration, describing a fixed amount of seconds / minutes / hours / milliseconds / etclength- The SILengthquantity,Meters,Feet, etcspeed- The SISpeedquantity,MetersPerSecond,Knots, etctemperature- The SITemperaturequantity,Celcius,Kelvin, etc